package com.mudu.quartz;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpRequest;
import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.mudu.entity.ASafeBqbhpx;
import com.mudu.entity.ASafeQyzypgl;
import com.mudu.service.ASafeBqbhpxService;
import com.mudu.service.ASafeQyzypglService;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;

/**
 * 班前班后以及特殊作业的数据接收
 *
 * @author wu
 * @since 2024/4/26 下午4:40
 */
//@RestController
//@RequestMapping("mudu/test")
//@Api(tags = "班前班后以及特殊作业的数据接收")
@Transactional(rollbackFor = Exception.class)
@Configuration
@EnableScheduling
public class BqbhTszyQuartz {

    @Resource
    private ASafeBqbhpxService safeBqbhpxService;

    @Resource
    private ASafeQyzypglService safeQyzypglService;

    @Value("${bqbhUrl}")
    private String bqbhUrl;

    @Value("${tszyUrl}")
    private String tszyUrl;

    @Value("${api}")
    private String api;


    /**
     * 保存班前班后数据
     */
//    @GetMapping("/bqbh")
//    @ApiOperation(value = "保存班前班后数据")
    @Scheduled(cron = "0 0 1 * * ? ")
    public void saveBqbh() {
        String res = HttpRequest.get(bqbhUrl).contentType("application/x-www-form-urlencoded;charset=UTF-8").execute().body();
        JSONObject resObj = JSON.parseObject(res);
        String dataList = resObj.getString("data");
        if (StrUtil.isEmpty(dataList)) {
            return;
        }
        List<ASafeBqbhpx> list = JSON.parseArray(dataList, ASafeBqbhpx.class);
        list.forEach(x -> {
            if (StrUtil.isNotEmpty(x.getPxxctp())) {
                x.setPxxctp(api + x.getPxxctp());
            }
        });
        if (CollectionUtil.isNotEmpty(list)) {
            safeBqbhpxService.saveBatch(list);
        }
    }

    /**
     * 保存特殊作业数据
     */
//    @GetMapping("/tszy")
//    @ApiOperation(value = "保存特殊作业数据")
    @Scheduled(cron = "0 0 1 * * ? ")
    public void saveTszy() {
        String res = HttpRequest.get(tszyUrl).contentType("application/x-www-form-urlencoded;charset=UTF-8").execute().body();
        JSONObject resObj = JSON.parseObject(res);
        String dataList = resObj.getString("data");
        if (StrUtil.isEmpty(dataList)) {
            return;
        }
        List<ASafeQyzypgl> list = JSON.parseArray(dataList, ASafeQyzypgl.class);
        if (CollectionUtil.isNotEmpty(list)) {
            safeQyzypglService.saveBatch(list);
        }
    }
}
